@@ -504,11 +504,7 @@ def _unionload(l: Loader, value, type_) -> Any:
     # Give a score to the types
     sorted_args = []  # type: List[Type]
     for t in args:
-        if (value_type == list and is_list(t)) or \
-           (value_type == dict and is_dict(t)) or \
-           (value_type == frozenset and is_frozenset(t)) or \
-           (value_type == set and is_set(t)) or \
-           (value_type == tuple and is_tuple(t)):
+        if t not in l.basictypes:
             sorted_args.insert(0, t)
         else:
             sorted_args.append(t)
